from colorama import Fore, Style
import sys
from sylo.models import Durations


def print_welcome():
    print(f'''{Fore.RED}                               
                  #%                        
          ,//(/*****/***/((##/              
      ,//////*      /.   ,//((((((          
    //////**    .           *(((((((,       
   (/////**   {Fore.YELLOW}%@@.{Style.RESET_ALL}     {Fore.YELLOW}@@@{Style.RESET_ALL}{Fore.RED}    *((((////      
  ,(//////*,      .*/,      ./((((///(      
  .(((///////*,,**,,*/////(#((((((((##      
   #(((((///////(/////(((////((((####/      
    ###(((((((.,/((##((*  /((((#####/       
     .######((/.      ...,######%%#         
        (%#######,.  .,#####%#%%*           
             .(%%%%%%%%%%#(.                
    
SYLO - A pomodoro timer for the terminal{Style.RESET_ALL}
    ''')


def print_message(message: str, timer_val: int = None):

    if message == 'work_start':
        sys.stdout.write("\033[K")
        print(
            f'{Fore.RED}WORK{Style.RESET_ALL} for {Fore.YELLOW}{timer_val}{Style.RESET_ALL} minutes',
            end="\r",
            flush=True
        )
    elif message == 'work_stop':
        sys.stdout.write("\033[K")
        print(
            f'{Fore.GREEN}WORK COMPLETED {Style.RESET_ALL}',
            end="\r",
            flush=True
        )
    elif message == 'work_countdown':
        sys.stdout.write("\033[K")
        print(
            f'{Fore.RED}WORK{Style.RESET_ALL} for {Fore.YELLOW}{timer_val}{Style.RESET_ALL} more seconds',
            end="\r",
            flush=True
        )
    elif message == 'break_start':
        sys.stdout.write("\033[K")
        print(
            f'Take a {Fore.GREEN}BREAK{Style.RESET_ALL} for {Fore.YELLOW}{timer_val}{Style.RESET_ALL} minutes',
            end="\r",
            flush=True
        )
    elif message == 'break_stop':
        sys.stdout.write("\033[K")
        print(
            f'{Fore.RED}BREAK OVER{Style.RESET_ALL}',
            end="\r",
            flush=True
        )
    elif message == 'break_countdown':
        sys.stdout.write("\033[K")
        print(
            f'Take a {Fore.GREEN}BREAK{Style.RESET_ALL} for {Fore.YELLOW}{timer_val}{Style.RESET_ALL} more seconds',
            end="\r",
            flush=True
        )


def print_update(durations: Durations):
    print(f'''
Work length:        {Fore.RED}{durations.work_mins} minutes{Style.RESET_ALL}
Break length:       {Fore.GREEN}{durations.break_mins} minutes{Style.RESET_ALL}
Total work time:    {Fore.YELLOW}{durations.total_mins} minutes{Style.RESET_ALL}

Press ENTER to start the timer or Q to exit
    ''')



import argparse


def get_arguments():
    parser = argparse.ArgumentParser(description='Sort Your Life Out! Python Pomodoro Timer')
    parser.add_argument("-w", "--work_time", help="Set the work time length", type=int)
    parser.add_argument("-b", "--break_time", help="Set the break time length", type=int)
    return parser.parse_args()


#!/usr/bin/env python
import argparse
import sys
import time
import os
import simpleaudio
from beepy import beep
from sylo.messages import print_message, print_welcome, print_update
from sylo.models import Durations, welcome_choices
from sylo.definitions import AUDIO_FILE_PATH


def get_first_file_in_directory(path: str):
    return path + os.listdir(path)[0]


def initialise_wav(file_path):
    try:
        return simpleaudio.WaveObject.from_wave_file(
            get_first_file_in_directory(file_path)
        )
    except IndexError:
        print(f"Can't find a valid file in {file_path}. Using stock sounds.")
        return 'beep'


def play_sound(sound_file: any, beep_sound: str = 'coin'):
    if sound_file == 'beep':
        beep(sound=beep_sound)
    else:
        beep(sound=beep_sound)
        play_obj = sound_file.play()
        play_obj.wait_done()


def flip_mins_and_secs(time_val: int, mins_to_secs: bool = True):
    if mins_to_secs:
        return int(time_val * 60)
    else:
        return int(time_val / 60)


def start_timer(timer_mins: int, mode: str):
    timer_secs = flip_mins_and_secs(timer_mins)
    while timer_secs > 0:
        if timer_secs % 60 == 0:
            print_message(f'{mode}_start', flip_mins_and_secs(timer_secs, False))
        if timer_secs < 60:
            print_message(f'{mode}_countdown', timer_secs)
        time.sleep(1)
        timer_secs -= 1
    print_message(f'{mode}_stop', flip_mins_and_secs(timer_secs, False))


def sylo(is_break: bool, durations: Durations, sound_obj: any):
    print_update(durations)
    response = input('> ')
    os.system('cls' if os.name == 'nt' else 'clear')

    while response.lower() not in welcome_choices:
        print_welcome()
        sylo(is_break, durations, sound_obj)
    while response.lower() == "q":
        sys.exit()
    while response == "":
        if is_break:
            start_timer(durations.break_mins, 'break')
            play_sound(sound_obj, 'ready')
            is_break = False
        else:
            start_timer(durations.work_mins, 'work')
            play_sound(sound_obj, 'success')
            durations.total_mins += durations.work_mins
            is_break = True
        sylo(is_break, durations, sound_obj)


def run(args):
    print_welcome()
    wave_obj = initialise_wav(AUDIO_FILE_PATH)
    play_sound(wave_obj, 'coin')
    break_time = False
    durations_data = Durations()

    if args.work_time:
        durations_data.work_mins = args.work_time
    if args.break_time:
        durations_data.break_mins = args.break_time
    sylo(break_time, durations_data, wave_obj)





from setuptools import setup

with open('README.md') as f:
    readme = f.read()

setup(name='sylo',
      version='0.8',
      description='SYLO Python Pomodoro Timer',
      long_description=readme,
      long_description_content_type='text/markdown',  # This is important!
      url='http://github.com/rob-parker-what/sylo',
      author='Rob Parker',
      author_email='robparkerwhat.dev@gmail.com',
      license='MIT',
      packages=['sylo'],
      entry_points={
          'console_scripts': ['sylo=sylo.cmdline:main'],
      },
      install_requires=[
            'colorama==0.4.4',
            'simpleaudio==1.0.4',
            'beepy==1.0.7',
      ],
      package_data={'sylo': ['audio/*.wav']},
      zip_safe=False)
